@@ -33,25 +33,22 @@ import java.util.TreeSet;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
-import javax.el.ValueExpression;
-import javax.faces.FacesException;
-import javax.faces.component.UIOutput;
-import javax.faces.component.UISelectMany;
-import javax.faces.context.FacesContext;
-import javax.faces.convert.Converter;
-import javax.faces.convert.ConverterException;
-import javax.faces.model.SelectItem;
-import javax.faces.model.SelectItemGroup;
+import jakarta.el.ValueExpression;
+import jakarta.faces.FacesException;
+import jakarta.faces.component.UIOutput;
+import jakarta.faces.component.UISelectMany;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.convert.Converter;
+import jakarta.faces.convert.ConverterException;
+import jakarta.faces.model.SelectItem;
+import jakarta.faces.model.SelectItemGroup;
 
 import org.apache.myfaces.shared.util.SelectItemsIterator;
 
 /**
- * The util methods in this class are shared between the javax.faces.component package and
+ * The util methods in this class are shared between the jakarta.faces.component package and
  * the org.apache.myfaces.renderkit package.
  * Please note: Any changes here must also apply to the class in the other package!
- *
- * @author Manfred Geiler (latest modification by $Author: lu4242 $)
- * @version $Revision: 1325542 $ $Date: 2012-04-12 21:54:16 +0000 (Thu, 12 Apr 2012) $
  */
 class _SharedRendererUtils
 {
