@@ -22,15 +22,15 @@ import java.io.IOException;
 import java.util.List;
 import java.util.Map;
 
-import javax.faces.component.UIComponent;
-import javax.faces.component.UIInput;
-import javax.faces.component.UIOutput;
-import javax.faces.component.behavior.ClientBehavior;
-import javax.faces.component.behavior.ClientBehaviorHolder;
-import javax.faces.component.html.HtmlInputTextarea;
-import javax.faces.context.FacesContext;
-import javax.faces.context.ResponseWriter;
-import javax.faces.convert.ConverterException;
+import jakarta.faces.component.UIComponent;
+import jakarta.faces.component.UIInput;
+import jakarta.faces.component.UIOutput;
+import jakarta.faces.component.behavior.ClientBehavior;
+import jakarta.faces.component.behavior.ClientBehaviorHolder;
+import jakarta.faces.component.html.HtmlInputTextarea;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.context.ResponseWriter;
+import jakarta.faces.convert.ConverterException;
 
 import org.apache.myfaces.shared.renderkit.RendererUtils;
 import org.apache.myfaces.shared.renderkit.html.util.ResourceUtils;
@@ -41,7 +41,8 @@ public class HtmlTextareaRendererBase
 {
     private static final String ADD_NEW_LINE_AT_START_ATTR = "org.apache.myfaces.addNewLineAtStart";
     
-    public void encodeEnd(FacesContext facesContext, UIComponent uiComponent)
+    @Override
+    public void encodeBegin(FacesContext facesContext, UIComponent uiComponent)
             throws IOException
     {
         RendererUtils.checkParamValidity(facesContext, uiComponent, UIInput.class);
@@ -52,23 +53,20 @@ public class HtmlTextareaRendererBase
             behaviors = ((ClientBehaviorHolder) uiComponent).getClientBehaviors();
             if (!behaviors.isEmpty())
             {
-                ResourceUtils.renderDefaultJsfJsInlineIfNecessary(facesContext, 
+                ResourceUtils.renderDefaultJsfJsInlineIfNecessary(facesContext,
                         facesContext.getResponseWriter());
             }
         }
-        
-        encodeTextArea(facesContext, uiComponent);
 
+        renderTextAreaBegin(facesContext, uiComponent);
     }
 
-    protected void encodeTextArea(FacesContext facesContext, UIComponent uiComponent) 
-        throws IOException
+    @Override
+    public void encodeEnd(FacesContext facesContext, UIComponent uiComponent)
+            throws IOException
     {
-       //allow subclasses to render custom attributes by separating rendering begin and end
-        renderTextAreaBegin(facesContext, uiComponent);
         renderTextAreaValue(facesContext, uiComponent);
         renderTextAreaEnd(facesContext, uiComponent);
-        
     }
 
     //Subclasses can set the value of an attribute before, or can render a custom attribute after calling this method
